# CreateBillingAdjustmentRequest


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**account_number** | **str** | The account number for which the adjustment is created.    **Note**: The account number should be of the subscription owner.  **Note**: Only one of accountNumber or subscriptionNumber should be provided.  | [optional] 
**charge_numbers** | **List[str]** | An optional container to specify charge numbers in the subscription for which the adjustment needs to be created.  | [optional] 
**deferred_revenue_accounting_code** | **str** | The accounting code for the deferred revenue, such as Monthly Recurring Liability.  | [optional] 
**end_date** | **date** | The end date of the adjustment, in &#x60;yyyy-mm-dd&#x60; format. This is inclusive.  | 
**exclusion** | [**List[BillingAdjustmentExclusion]**](BillingAdjustmentExclusion.md) | The charge numbers and the corresponding dates for exclusion of adjustment.  | [optional] 
**reason** | **str** | The reason for the adjustment.  | [optional] 
**recognized_revenue_accounting_code** | **str** | The accounting code for the recognized revenue, such as Monthly Recurring Charges or Overage Charges.  | [optional] 
**revenue_recognition_rule_name** | **str** | The name of the revenue recognition rule governing the revenue schedule.  | [optional] 
**start_date** | **date** | The start date of the adjustment, in &#x60;yyyy-mm-dd&#x60; format. This is inclusive.  | 
**subscription_number** | **str** | The subscription number for which the adjustment is created.  **Note**: Only one of accountNumber or subscriptionNumber should be provided.  | [optional] 
**type** | [**BillingAdjustmentType**](BillingAdjustmentType.md) |  | [optional] 
**credit_memo_custom_fields** | **Dict[str, object]** | Container for custom fields of the Credit Memo. The custom fields of the Credit Memo can be defined during Create Adjustment  | [optional] 

## Example

```python
from zuora_sdk.models.create_billing_adjustment_request import CreateBillingAdjustmentRequest

# TODO update the JSON string below
json = "{}"
# create an instance of CreateBillingAdjustmentRequest from a JSON string
create_billing_adjustment_request_instance = CreateBillingAdjustmentRequest.from_json(json)
# print the JSON string representation of the object
print(CreateBillingAdjustmentRequest.to_json())

# convert the object into a dict
create_billing_adjustment_request_dict = create_billing_adjustment_request_instance.to_dict()
# create an instance of CreateBillingAdjustmentRequest from a dict
create_billing_adjustment_request_from_dict = CreateBillingAdjustmentRequest.from_dict(create_billing_adjustment_request_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


